@@ -11,6 +11,7 @@ pub struct Config {
     pub formatting: FormattingConfig,
     pub synctex: Option<SynctexConfig>,
     pub symbols: SymbolConfig,
+    pub hover: HoverConfig,
     pub syntax: SyntaxConfig,
     pub completion: CompletionConfig,
     pub inlay_hints: InlayHintConfig,
@@ -86,6 +87,18 @@ pub struct SymbolEnvironmentConfig {
     pub label: bool,
 }
 
+#[derive(Debug)]
+pub struct HoverConfig {
+    pub symbols: HoverSymbolConfig,
+}
+
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
+pub enum HoverSymbolConfig {
+    None,
+    Glyph,
+    Image,
+}
+
 #[derive(Debug)]
 pub struct InlayHintConfig {
     pub label_definitions: bool,
@@ -163,3 +176,11 @@ impl Default for CompletionConfig {
         }
     }
 }
+
+impl Default for HoverConfig {
+    fn default() -> Self {
+        Self {
+            symbols: HoverSymbolConfig::Image,
+        }
+    }
+}
