@@ -6,6 +6,6 @@ mod root;
 pub use self::{
     discover::{discover, watch},
     graph::{DirectLinkData, Edge, EdgeData, Graph, HOME_DIR},
-    project::{parents, Project},
+    project::{Project, parents},
     root::ProjectRoot,
 };
