@@ -9,7 +9,7 @@ use rowan::{TextLen, TextRange};
 use rustc_hash::{FxHashMap, FxHashSet};
 use url::Url;
 
-use crate::{deps, Config, Document, DocumentParams, Owner};
+use crate::{Config, Document, DocumentParams, Owner, deps};
 
 #[derive(Debug, Default)]
 pub struct Workspace {
@@ -41,7 +41,7 @@ impl Workspace {
         self.iter().filter(move |doc| {
             doc.path
                 .as_deref()
-                .map_or(false, |p| p.starts_with(file_or_dir))
+                .is_some_and(|p| p.starts_with(file_or_dir))
         })
     }
 
