@@ -6,8 +6,8 @@ use syntax::latex::SyntaxKind::{self, *};
 use crate::SyntaxConfig;
 
 use self::lexer::{
-    types::{CommandName, ParagraphLevel, SectionLevel, Token},
     Lexer,
+    types::{CommandName, ParagraphLevel, SectionLevel, Token},
 };
 
 #[derive(Debug, Clone, Copy)]
@@ -79,7 +79,7 @@ impl<'a> Parser<'a> {
     }
 
     fn trivia(&mut self) {
-        while self.peek().map_or(false, |kind| {
+        while self.peek().is_some_and(|kind| {
             matches!(
                 kind,
                 Token::LineBreak | Token::Whitespace | Token::LineComment
@@ -267,12 +267,15 @@ impl<'a> Parser<'a> {
                         | Token::Word
                         | Token::Pipe
                         | Token::Comma
+                        | Token::LCurly
                 )
             })
             .is_some()
         {
             if self.peek() == Some(Token::Word) {
                 self.key();
+            } else if self.peek() == Some(Token::LCurly) {
+                self.curly_group_word_list();
             } else {
                 self.eat();
             }
@@ -298,7 +301,7 @@ impl<'a> Parser<'a> {
     fn brack_group(&mut self) {
         self.builder.start_node(BRACK_GROUP.into());
         self.eat();
-        while self.peek().map_or(false, |kind| {
+        while self.peek().is_some_and(|kind| {
             !matches!(
                 kind,
                 Token::RCurly
@@ -337,7 +340,7 @@ impl<'a> Parser<'a> {
         self.builder.start_node(MIXED_GROUP.into());
         self.eat();
         self.trivia();
-        while self.peek().map_or(false, |kind| {
+        while self.peek().is_some_and(|kind| {
             !matches!(
                 kind,
                 Token::RCurly
@@ -943,7 +946,11 @@ impl<'a> Parser<'a> {
         self.eat();
         self.trivia();
 
-        if self.lexer.peek() == Some(Token::LCurly) {
+        let token = self.lexer.peek();
+        if matches!(token, Some(Token::CommandName(_))) {
+            self.eat();
+            self.trivia();
+        } else if token == Some(Token::LCurly) {
             self.curly_group_command();
         }
 
