@@ -27,7 +27,7 @@ impl<'a> From<&'a Workspace> for ProjectOrdering<'a> {
         let inner = sorted_documents()
             .filter(|document| {
                 let data = document.data.as_tex();
-                data.map_or(false, |data| data.semantics.can_be_root)
+                data.is_some_and(|data| data.semantics.can_be_root)
             })
             .chain(sorted_documents())
             .flat_map(|document| {
