@@ -13,6 +13,7 @@ pub struct Options {
     pub diagnostics: DiagnosticsOptions,
     pub diagnostics_delay: Option<u64>,
     pub build: BuildOptions,
+    pub hover: HoverOptions,
     pub chktex: ChktexOptions,
     pub symbols: SymbolOptions,
     pub latexindent: LatexindentOptions,
@@ -76,6 +77,21 @@ pub struct BuildOptions {
     pub use_file_list: bool,
 }
 
+#[derive(Debug, PartialEq, Eq, Clone, Default, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
+#[serde(default)]
+pub struct HoverOptions {
+    pub symbols: Option<HoverSymbolOptions>,
+}
+
+#[derive(Debug, PartialEq, Eq, Clone, Copy, Serialize, Deserialize)]
+#[serde(rename_all = "kebab-case")]
+pub enum HoverSymbolOptions {
+    None,
+    Glyph,
+    Image,
+}
+
 #[derive(Debug, PartialEq, Eq, Clone, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[serde(default)]
@@ -140,6 +156,7 @@ pub struct ExperimentalOptions {
     pub enum_environments: Vec<String>,
     pub verbatim_environments: Vec<String>,
     pub citation_commands: Vec<String>,
+    pub glossary_reference_commands: Vec<String>,
     pub label_definition_commands: Vec<String>,
     pub label_definition_prefixes: Vec<(String, String)>,
     pub label_reference_commands: Vec<String>,
