@@ -1,7 +1,8 @@
-use std::collections::HashMap;
+use std::{collections::HashMap, str::FromStr};
 
 use base_db::{
-    data::BibtexEntryTypeCategory, util::RenderedObject, Document, DocumentLocation, Workspace,
+    Config, Document, DocumentLocation, HoverSymbolConfig, Workspace,
+    data::BibtexEntryTypeCategory, util::RenderedObject,
 };
 use definition::DefinitionResult;
 use diagnostics::{BibError, ChktexSeverity, Diagnostic, TexError};
@@ -15,7 +16,11 @@ use rename::RenameResult;
 use rowan::TextRange;
 use syntax::BuildErrorLevel;
 
-use super::{line_index_ext::LineIndexExt, ClientFlags};
+use super::{ClientFlags, line_index_ext::LineIndexExt};
+
+pub fn uri(url: &url::Url) -> lsp_types::Uri {
+    lsp_types::Uri::from_str(url.as_str()).expect("valid URL")
+}
 
 pub fn diagnostic(
     workspace: &Workspace,
@@ -140,7 +145,7 @@ pub fn diagnostic(
 
     fn make_conflict_info(
         workspace: &Workspace,
-        locations: &Vec<(lsp_types::Url, TextRange)>,
+        locations: &Vec<(url::Url, TextRange)>,
         object: &str,
     ) -> Option<Vec<lsp_types::DiagnosticRelatedInformation>> {
         let mut items = Vec::new();
@@ -151,7 +156,7 @@ pub fn diagnostic(
                 .line_col_lsp_range(*range)?;
 
             let message = format!("conflicting {object} defined here");
-            let location = lsp_types::Location::new(uri.clone(), range);
+            let location = lsp_types::Location::new(self::uri(&uri), range);
             items.push(lsp_types::DiagnosticRelatedInformation { location, message });
         }
 
@@ -261,7 +266,7 @@ pub fn document_link(
     Some(lsp_types::DocumentLink {
         data: None,
         tooltip: None,
-        target: Some(link.document.uri.clone()),
+        target: Some(self::uri(&link.document.uri)),
         range: line_index.line_col_lsp_range(link.range)?,
     })
 }
@@ -299,7 +304,7 @@ pub fn location_link(
     let origin_selection_range = line_index.line_col_lsp_range(result.origin_selection_range);
 
     let target_line_index = &result.target.line_index;
-    let target_uri = result.target.uri.clone();
+    let target_uri = self::uri(&result.target.uri);
     let target_range = target_line_index.line_col_lsp_range(result.target_range)?;
     let target_selection_range =
         target_line_index.line_col_lsp_range(result.target_selection_range)?;
@@ -347,7 +352,7 @@ pub fn symbol_information(
         name: symbol.name,
         kind: symbol_kind(symbol.kind),
         deprecated: Some(false),
-        location: lsp_types::Location::new(document.uri.clone(), range),
+        location: lsp_types::Location::new(self::uri(&document.uri), range),
         tags: None,
         container_name: None,
     });
@@ -381,6 +386,7 @@ pub fn symbol_kind(value: symbols::SymbolKind) -> lsp_types::SymbolKind {
         },
         symbols::SymbolKind::Field => lsp_types::SymbolKind::FIELD,
         symbols::SymbolKind::Environment => lsp_types::SymbolKind::FUNCTION,
+        symbols::SymbolKind::CommandDefinition => lsp_types::SymbolKind::KEY,
     }
 }
 
@@ -422,7 +428,7 @@ pub fn workspace_edit(result: RenameResult, new_name: &str) -> lsp_types::Worksp
             })
             .for_each(|(range, new_name)| edits.push(lsp_types::TextEdit::new(range, new_name)));
 
-        changes.insert(document.uri.clone(), edits);
+        changes.insert(self::uri(&document.uri), edits);
     }
 
     lsp_types::WorkspaceEdit::new(changes)
@@ -431,7 +437,7 @@ pub fn workspace_edit(result: RenameResult, new_name: &str) -> lsp_types::Worksp
 pub fn location(location: DocumentLocation) -> Option<lsp_types::Location> {
     let document = location.document;
     let range = document.line_index.line_col_lsp_range(location.range)?;
-    Some(lsp_types::Location::new(document.uri.clone(), range))
+    Some(lsp_types::Location::new(self::uri(&document.uri), range))
 }
 
 pub fn document_highlight(
@@ -451,26 +457,37 @@ pub fn hover(
     hover: Hover,
     line_index: &LineIndex,
     client_flags: &ClientFlags,
+    config: &Config,
 ) -> Option<lsp_types::Hover> {
     fn inline_image(
         command: &completion_data::Command,
-
         client_flags: &ClientFlags,
+        config: &Config,
     ) -> Option<lsp_types::MarkupContent> {
         let name = &command.name;
         command
             .image
             .map(|base64| format!("![{name}](data:image/png;base64,{base64}|width=48,height=48)"))
             .filter(|_| client_flags.hover_markdown)
-            .map(|value| lsp_types::MarkupContent {
-                kind: lsp_types::MarkupKind::Markdown,
-                value,
+            .and_then(|value| {
+                if config.hover.symbols == HoverSymbolConfig::Image {
+                    Some(lsp_types::MarkupContent {
+                        kind: lsp_types::MarkupKind::Markdown,
+                        value,
+                    })
+                } else {
+                    None
+                }
             })
             .or_else(|| {
-                Some(lsp_types::MarkupContent {
-                    kind: lsp_types::MarkupKind::PlainText,
-                    value: command.glyph.as_deref()?.into(),
-                })
+                if config.hover.symbols == HoverSymbolConfig::Glyph {
+                    Some(lsp_types::MarkupContent {
+                        kind: lsp_types::MarkupKind::PlainText,
+                        value: command.glyph.as_deref()?.into(),
+                    })
+                } else {
+                    None
+                }
             })
     }
 
@@ -483,7 +500,7 @@ pub fn hover(
             kind: lsp_types::MarkupKind::PlainText,
             value: description.into(),
         },
-        HoverData::Command(command) => inline_image(command, client_flags)?,
+        HoverData::Command(command) => inline_image(command, client_flags, config)?,
         HoverData::EntryType(type_) => lsp_types::MarkupContent {
             kind: lsp_types::MarkupKind::Markdown,
             value: type_.documentation?.into(),
